from Utils.StaticUtils import StaticUtils as Utils
from Utils.Enums import DeviceType


class StateDevice(object):
    def __init__(self, inputDict):
        self.Key = inputDict["key"]
        self.IsTampered = inputDict["isTampered"]
        self.HasLowBattery = inputDict["hasLowBattery"]
        self.HasSupervisionFault = inputDict["hasSupervisionFault"]
        self.IsOpen = inputDict["isOpen"]
        self.IsLocked = inputDict["isLocked"]
        self.IsLockout = inputDict["isLockout"]
        self.IsTriggeredAlarm = inputDict["isTriggeredAlarm"]
        self.AlarmType = inputDict["alarmType"]
        self.UserName = inputDict["userName"]
        self.SerialNumber = inputDict["serialNumber"]
        self.DayPartition = inputDict["dayPartition"]
        self.NightPartition = inputDict["nightPartition"]
        self.RfLevel = inputDict["rfLevel"]
        self.BatteryLevel = inputDict["batteryLevel"]
        self.TemperatureLevel = inputDict["temperatureLevel"]
        self.SubType = inputDict["subType"]
        self.Attributes = inputDict["attributes"]
        self.HardwareDeviceType = inputDict["hardwareDeviceType"]
        self.RoleGroupId = inputDict["roleGroupId"]
        self.BypassState = inputDict["bypassState"]
        self.LockChangedByUser = inputDict["lockChangedByUser"]
        self.LockChangedByDeviceNumber = inputDict["lockChangedByDeviceNumber"]
        self.LockChangedByDeviceType = inputDict["lockChangedByDeviceType"]
        self.AssociatedOutputType = inputDict["associatedOutputType"]
        self.AssociatedOutputId = inputDict["associatedOutputId"]
        self.Owner = inputDict["owner"]
        self.PanelUpdateTime = Utils.ParseDate(inputDict["panelUpdateTime"])
        self.UpdateTime = Utils.ParseDate(inputDict["updateTime"])
        self.Chime = inputDict["chime"]
        self.SecurityMode = inputDict["securityMode"]
        self.IsOutdoorMode = inputDict["isOutdoorMode"]
        self.IsBeepEnable = inputDict["isBeepEnable"]
        self.FullExitBeepsEnabled = inputDict["fullExitBeepsEnabled"]
        self.DoorBellEnabled = inputDict["doorBellEnabled"]
        self.SubDeviceType = inputDict["subDeviceType"]
        self.PanelDeviceId = inputDict["panelDeviceId"]
        self.IsNormallyOpen = inputDict["isNormallyOpen"]
        self.IsPulseDevice = inputDict["isPulseDevice"]
        self.UtDeviceType = inputDict["utDeviceType"]
        self.AdditionalData = inputDict["additionalData"]
        self.AddedOrResetTime = Utils.ParseDate(inputDict["addedOrResetTime"])
        self.PkId = inputDict["PkId"]
        self.Id = inputDict["Id"]
        self.TypeId = inputDict["Type"]
        self.Type = DeviceType(inputDict["Type"])
        self.Name = inputDict["Name"]
        self.ParentDeviceId = inputDict["ParentDeviceId"]
        self.PanelId = inputDict["PanelId"]


if __name__ == "__main__":
    vals = [
        {
            "key": None,
            "isTampered": False,
            "hasLowBattery": False,
            "hasSupervisionFault": False,
            "isOpen": False,
            "isLocked": False,
            "isLockout": None,
            "isTriggeredAlarm": False,
            "alarmType": 0,
            "userName": None,
            "serialNumber": "000E2F49",
            "dayPartition": False,
            "nightPartition": True,
            "rfLevel": 5,
            "batteryLevel": 96,
            "temperatureLevel": 24,
            "subType": None,
            "attributes": None,
            "hardwareDeviceType": 3,
            "roleGroupId": 1,
            "bypassState": 0,
            "lockChangedByUser": None,
            "lockChangedByDeviceNumber": None,
            "lockChangedByDeviceType": None,
            "associatedOutputType": 0,
            "associatedOutputId": None,
            "owner": None,
            "panelUpdateTime": "2021-01-04T14:44:03Z",
            "updateTime": "2021-01-04T13:44:03Z",
            "chime": False,
            "securityMode": 16,
            "isOutdoorMode": None,
            "isBeepEnable": None,
            "fullExitBeepsEnabled": None,
            "doorBellEnabled": None,
            "subDeviceType": None,
            "panelDeviceId": None,
            "isNormallyOpen": None,
            "isPulseDevice": None,
            "utDeviceType": None,
            "additionalData": None,
            "addedOrResetTime": "2020-12-01T15:42:01Z",
            "PkId": 955543,
            "Id": 1,
            "Type": 2,
            "Name": "Indgang",
            "ParentDeviceId": None,
            "PanelId": 10039947,
        },
        {
            "key": None,
            "isTampered": False,
            "hasLowBattery": False,
            "hasSupervisionFault": False,
            "isOpen": False,
            "isLocked": False,
            "isLockout": None,
            "isTriggeredAlarm": False,
            "alarmType": 0,
            "userName": None,
            "serialNumber": "000E3A40",
            "dayPartition": False,
            "nightPartition": True,
            "rfLevel": 5,
            "batteryLevel": 98,
            "temperatureLevel": 21,
            "subType": None,
            "attributes": None,
            "hardwareDeviceType": 3,
            "roleGroupId": 1,
            "bypassState": 0,
            "lockChangedByUser": None,
            "lockChangedByDeviceNumber": None,
            "lockChangedByDeviceType": None,
            "associatedOutputType": 0,
            "associatedOutputId": None,
            "owner": None,
            "panelUpdateTime": "2021-01-04T13:23:16Z",
            "updateTime": "2021-01-04T12:23:17Z",
            "chime": False,
            "securityMode": 8,
            "isOutdoorMode": None,
            "isBeepEnable": None,
            "fullExitBeepsEnabled": None,
            "doorBellEnabled": None,
            "subDeviceType": None,
            "panelDeviceId": None,
            "isNormallyOpen": None,
            "isPulseDevice": None,
            "utDeviceType": None,
            "additionalData": None,
            "addedOrResetTime": "2020-12-01T15:42:52Z",
            "PkId": 955547,
            "Id": 2,
            "Type": 2,
            "Name": "Vindue spisestue",
            "ParentDeviceId": None,
            "PanelId": 10039947,
        },
        {
            "key": None,
            "isTampered": False,
            "hasLowBattery": False,
            "hasSupervisionFault": False,
            "isOpen": False,
            "isLocked": False,
            "isLockout": None,
            "isTriggeredAlarm": False,
            "alarmType": 0,
            "userName": None,
            "serialNumber": "000E65BA",
            "dayPartition": False,
            "nightPartition": True,
            "rfLevel": 4,
            "batteryLevel": 99,
            "temperatureLevel": 18,
            "subType": None,
            "attributes": None,
            "hardwareDeviceType": 3,
            "roleGroupId": 1,
            "bypassState": 0,
            "lockChangedByUser": None,
            "lockChangedByDeviceNumber": None,
            "lockChangedByDeviceType": None,
            "associatedOutputType": 0,
            "associatedOutputId": None,
            "owner": None,
            "panelUpdateTime": "2021-01-04T13:51:01Z",
            "updateTime": "2021-01-04T12:51:01Z",
            "chime": False,
            "securityMode": 8,
            "isOutdoorMode": None,
            "isBeepEnable": None,
            "fullExitBeepsEnabled": None,
            "doorBellEnabled": None,
            "subDeviceType": None,
            "panelDeviceId": None,
            "isNormallyOpen": None,
            "isPulseDevice": None,
            "utDeviceType": None,
            "additionalData": None,
            "addedOrResetTime": "2020-12-01T15:43:34Z",
            "PkId": 955549,
            "Id": 3,
            "Type": 2,
            "Name": "Børneværelset",
            "ParentDeviceId": None,
            "PanelId": 10039947,
        },
        {
            "key": None,
            "isTampered": False,
            "hasLowBattery": False,
            "hasSupervisionFault": False,
            "isOpen": False,
            "isLocked": False,
            "isLockout": None,
            "isTriggeredAlarm": False,
            "alarmType": 0,
            "userName": None,
            "serialNumber": "000E9CA2",
            "dayPartition": False,
            "nightPartition": True,
            "rfLevel": 5,
            "batteryLevel": 100,
            "temperatureLevel": 20,
            "subType": None,
            "attributes": None,
            "hardwareDeviceType": 3,
            "roleGroupId": 1,
            "bypassState": 0,
            "lockChangedByUser": None,
            "lockChangedByDeviceNumber": None,
            "lockChangedByDeviceType": None,
            "associatedOutputType": 0,
            "associatedOutputId": None,
            "owner": None,
            "panelUpdateTime": "2021-01-04T14:52:42Z",
            "updateTime": "2021-01-04T13:52:42Z",
            "chime": False,
            "securityMode": 8,
            "isOutdoorMode": None,
            "isBeepEnable": None,
            "fullExitBeepsEnabled": None,
            "doorBellEnabled": None,
            "subDeviceType": None,
            "panelDeviceId": None,
            "isNormallyOpen": None,
            "isPulseDevice": None,
            "utDeviceType": None,
            "additionalData": None,
            "addedOrResetTime": "2020-12-01T15:44:43Z",
            "PkId": 955552,
            "Id": 4,
            "Type": 2,
            "Name": "Soveværelse",
            "ParentDeviceId": None,
            "PanelId": 10039947,
        },
        {
            "key": None,
            "isTampered": False,
            "hasLowBattery": False,
            "hasSupervisionFault": False,
            "isOpen": False,
            "isLocked": False,
            "isLockout": None,
            "isTriggeredAlarm": False,
            "alarmType": 0,
            "userName": None,
            "serialNumber": "000F2B9D",
            "dayPartition": False,
            "nightPartition": True,
            "rfLevel": 5,
            "batteryLevel": 100,
            "temperatureLevel": 20,
            "subType": None,
            "attributes": None,
            "hardwareDeviceType": 3,
            "roleGroupId": 1,
            "bypassState": 0,
            "lockChangedByUser": None,
            "lockChangedByDeviceNumber": None,
            "lockChangedByDeviceType": None,
            "associatedOutputType": 0,
            "associatedOutputId": None,
            "owner": None,
            "panelUpdateTime": "2021-01-04T14:56:29Z",
            "updateTime": "2021-01-04T13:56:29Z",
            "chime": False,
            "securityMode": 8,
            "isOutdoorMode": None,
            "isBeepEnable": None,
            "fullExitBeepsEnabled": None,
            "doorBellEnabled": None,
            "subDeviceType": None,
            "panelDeviceId": None,
            "isNormallyOpen": None,
            "isPulseDevice": None,
            "utDeviceType": None,
            "additionalData": None,
            "addedOrResetTime": "2020-12-01T15:45:32Z",
            "PkId": 955553,
            "Id": 5,
            "Type": 2,
            "Name": "Terrassedør",
            "ParentDeviceId": None,
            "PanelId": 10039947,
        },
        {
            "key": None,
            "isTampered": False,
            "hasLowBattery": False,
            "hasSupervisionFault": False,
            "isOpen": False,
            "isLocked": False,
            "isLockout": None,
            "isTriggeredAlarm": False,
            "alarmType": 0,
            "userName": None,
            "serialNumber": "000FFB89",
            "dayPartition": False,
            "nightPartition": True,
            "rfLevel": 5,
            "batteryLevel": 100,
            "temperatureLevel": 21,
            "subType": None,
            "attributes": None,
            "hardwareDeviceType": 3,
            "roleGroupId": 1,
            "bypassState": 0,
            "lockChangedByUser": None,
            "lockChangedByDeviceNumber": None,
            "lockChangedByDeviceType": None,
            "associatedOutputType": 0,
            "associatedOutputId": None,
            "owner": None,
            "panelUpdateTime": "2021-01-04T13:23:16Z",
            "updateTime": "2021-01-04T12:23:17Z",
            "chime": False,
            "securityMode": 8,
            "isOutdoorMode": None,
            "isBeepEnable": None,
            "fullExitBeepsEnabled": None,
            "doorBellEnabled": None,
            "subDeviceType": None,
            "panelDeviceId": None,
            "isNormallyOpen": None,
            "isPulseDevice": None,
            "utDeviceType": None,
            "additionalData": None,
            "addedOrResetTime": "2020-12-01T15:46:00Z",
            "PkId": 955554,
            "Id": 6,
            "Type": 2,
            "Name": "Stuevindue",
            "ParentDeviceId": None,
            "PanelId": 10039947,
        },
        {
            "key": None,
            "isTampered": False,
            "hasLowBattery": False,
            "hasSupervisionFault": False,
            "isOpen": False,
            "isLocked": False,
            "isLockout": None,
            "isTriggeredAlarm": False,
            "alarmType": 0,
            "userName": None,
            "serialNumber": "000E307D",
            "dayPartition": False,
            "nightPartition": True,
            "rfLevel": 2,
            "batteryLevel": 98,
            "temperatureLevel": 21,
            "subType": None,
            "attributes": None,
            "hardwareDeviceType": 3,
            "roleGroupId": 1,
            "bypassState": 0,
            "lockChangedByUser": None,
            "lockChangedByDeviceNumber": None,
            "lockChangedByDeviceType": None,
            "associatedOutputType": 0,
            "associatedOutputId": None,
            "owner": None,
            "panelUpdateTime": "2021-01-04T14:19:29Z",
            "updateTime": "2021-01-04T13:19:29Z",
            "chime": False,
            "securityMode": 8,
            "isOutdoorMode": None,
            "isBeepEnable": None,
            "fullExitBeepsEnabled": None,
            "doorBellEnabled": None,
            "subDeviceType": None,
            "panelDeviceId": None,
            "isNormallyOpen": None,
            "isPulseDevice": None,
            "utDeviceType": None,
            "additionalData": None,
            "addedOrResetTime": "2020-12-01T15:47:27Z",
            "PkId": 955555,
            "Id": 7,
            "Type": 2,
            "Name": "Kontor",
            "ParentDeviceId": None,
            "PanelId": 10039947,
        },
        {
            "key": None,
            "isTampered": False,
            "hasLowBattery": False,
            "hasSupervisionFault": False,
            "isOpen": False,
            "isLocked": False,
            "isLockout": None,
            "isTriggeredAlarm": False,
            "alarmType": 0,
            "userName": None,
            "serialNumber": "000191D3",
            "dayPartition": False,
            "nightPartition": False,
            "rfLevel": 2,
            "batteryLevel": 100,
            "temperatureLevel": 20,
            "subType": None,
            "attributes": None,
            "hardwareDeviceType": 2,
            "roleGroupId": 1,
            "bypassState": 0,
            "lockChangedByUser": None,
            "lockChangedByDeviceNumber": None,
            "lockChangedByDeviceType": None,
            "associatedOutputType": 0,
            "associatedOutputId": None,
            "owner": None,
            "panelUpdateTime": "2021-01-04T14:39:33Z",
            "updateTime": "2021-01-04T13:39:33Z",
            "chime": False,
            "securityMode": 8,
            "isOutdoorMode": False,
            "isBeepEnable": True,
            "fullExitBeepsEnabled": False,
            "doorBellEnabled": False,
            "subDeviceType": None,
            "panelDeviceId": None,
            "isNormallyOpen": None,
            "isPulseDevice": None,
            "utDeviceType": None,
            "additionalData": None,
            "addedOrResetTime": "2020-12-01T15:57:33Z",
            "PkId": 955568,
            "Id": 56,
            "Type": 14,
            "Name": "Betjeningspanel indgang",
            "ParentDeviceId": None,
            "PanelId": 10039947,
        },
        {
            "key": None,
            "isTampered": False,
            "hasLowBattery": False,
            "hasSupervisionFault": False,
            "isOpen": False,
            "isLocked": False,
            "isLockout": None,
            "isTriggeredAlarm": False,
            "alarmType": 0,
            "userName": None,
            "serialNumber": "0004CB63",
            "dayPartition": False,
            "nightPartition": False,
            "rfLevel": 4,
            "batteryLevel": 87,
            "temperatureLevel": 28,
            "subType": None,
            "attributes": None,
            "hardwareDeviceType": 7,
            "roleGroupId": 1,
            "bypassState": 0,
            "lockChangedByUser": None,
            "lockChangedByDeviceNumber": None,
            "lockChangedByDeviceType": None,
            "associatedOutputType": 0,
            "associatedOutputId": None,
            "owner": None,
            "panelUpdateTime": "2021-01-04T14:30:08Z",
            "updateTime": "2021-01-04T13:30:08Z",
            "chime": False,
            "securityMode": 2,
            "isOutdoorMode": None,
            "isBeepEnable": None,
            "fullExitBeepsEnabled": None,
            "doorBellEnabled": None,
            "subDeviceType": None,
            "panelDeviceId": None,
            "isNormallyOpen": None,
            "isPulseDevice": None,
            "utDeviceType": None,
            "additionalData": None,
            "addedOrResetTime": "2020-12-01T15:51:01Z",
            "PkId": 955561,
            "Id": 1,
            "Type": 16,
            "Name": "SmokeAlarm spisestue",
            "ParentDeviceId": None,
            "PanelId": 10039947,
        },
        {
            "key": None,
            "isTampered": False,
            "hasLowBattery": False,
            "hasSupervisionFault": False,
            "isOpen": False,
            "isLocked": False,
            "isLockout": None,
            "isTriggeredAlarm": False,
            "alarmType": 0,
            "userName": None,
            "serialNumber": "0004C16F",
            "dayPartition": False,
            "nightPartition": False,
            "rfLevel": 5,
            "batteryLevel": 88,
            "temperatureLevel": 28,
            "subType": None,
            "attributes": None,
            "hardwareDeviceType": 7,
            "roleGroupId": 1,
            "bypassState": 0,
            "lockChangedByUser": None,
            "lockChangedByDeviceNumber": None,
            "lockChangedByDeviceType": None,
            "associatedOutputType": 0,
            "associatedOutputId": None,
            "owner": None,
            "panelUpdateTime": "2021-01-04T15:05:17Z",
            "updateTime": "2021-01-04T14:05:17Z",
            "chime": False,
            "securityMode": 2,
            "isOutdoorMode": None,
            "isBeepEnable": None,
            "fullExitBeepsEnabled": None,
            "doorBellEnabled": None,
            "subDeviceType": None,
            "panelDeviceId": None,
            "isNormallyOpen": None,
            "isPulseDevice": None,
            "utDeviceType": None,
            "additionalData": None,
            "addedOrResetTime": "2020-12-01T15:54:01Z",
            "PkId": 955563,
            "Id": 2,
            "Type": 16,
            "Name": "SmokeAlarm stue",
            "ParentDeviceId": None,
            "PanelId": 10039947,
        },
        {
            "key": None,
            "isTampered": False,
            "hasLowBattery": False,
            "hasSupervisionFault": False,
            "isOpen": None,
            "isLocked": False,
            "isLockout": None,
            "isTriggeredAlarm": False,
            "alarmType": 0,
            "userName": None,
            "serialNumber": "0003E600",
            "dayPartition": False,
            "nightPartition": False,
            "rfLevel": 4,
            "batteryLevel": 100,
            "temperatureLevel": 22,
            "subType": None,
            "attributes": None,
            "hardwareDeviceType": None,
            "roleGroupId": 1,
            "bypassState": 0,
            "lockChangedByUser": None,
            "lockChangedByDeviceNumber": None,
            "lockChangedByDeviceType": None,
            "associatedOutputType": None,
            "associatedOutputId": None,
            "owner": None,
            "panelUpdateTime": "2021-01-04T12:30:37Z",
            "updateTime": "2021-01-04T11:30:37Z",
            "chime": False,
            "securityMode": None,
            "isOutdoorMode": None,
            "isBeepEnable": None,
            "fullExitBeepsEnabled": None,
            "doorBellEnabled": None,
            "subDeviceType": None,
            "panelDeviceId": None,
            "isNormallyOpen": None,
            "isPulseDevice": None,
            "utDeviceType": None,
            "additionalData": None,
            "addedOrResetTime": "2020-12-01T15:56:42Z",
            "PkId": 955567,
            "Id": 1,
            "Type": 24,
            "Name": "Siren-1",
            "ParentDeviceId": None,
            "PanelId": 10039947,
        },
        {
            "petImmune": False,
            "key": None,
            "isTampered": False,
            "hasLowBattery": False,
            "hasSupervisionFault": False,
            "isOpen": False,
            "isLocked": False,
            "isLockout": None,
            "isTriggeredAlarm": False,
            "alarmType": 0,
            "userName": None,
            "serialNumber": "00084153",
            "dayPartition": False,
            "nightPartition": False,
            "rfLevel": 4,
            "batteryLevel": 87,
            "temperatureLevel": 22,
            "subType": None,
            "attributes": None,
            "hardwareDeviceType": 5,
            "roleGroupId": 1,
            "bypassState": 0,
            "lockChangedByUser": None,
            "lockChangedByDeviceNumber": None,
            "lockChangedByDeviceType": None,
            "associatedOutputType": 0,
            "associatedOutputId": None,
            "owner": None,
            "panelUpdateTime": "2021-01-04T13:23:16Z",
            "updateTime": "2021-01-04T12:23:17Z",
            "chime": False,
            "securityMode": 8,
            "isOutdoorMode": None,
            "isBeepEnable": None,
            "fullExitBeepsEnabled": None,
            "doorBellEnabled": None,
            "subDeviceType": None,
            "panelDeviceId": None,
            "isNormallyOpen": None,
            "isPulseDevice": None,
            "utDeviceType": None,
            "additionalData": None,
            "addedOrResetTime": "2020-12-01T15:48:17Z",
            "PkId": 955557,
            "Id": 8,
            "Type": 38,
            "Name": "Video kontor",
            "ParentDeviceId": None,
            "PanelId": 10039947,
        },
        {
            "petImmune": False,
            "key": None,
            "isTampered": False,
            "hasLowBattery": False,
            "hasSupervisionFault": False,
            "isOpen": False,
            "isLocked": False,
            "isLockout": None,
            "isTriggeredAlarm": False,
            "alarmType": 0,
            "userName": None,
            "serialNumber": "00087FEA",
            "dayPartition": False,
            "nightPartition": False,
            "rfLevel": 4,
            "batteryLevel": 93,
            "temperatureLevel": 22,
            "subType": None,
            "attributes": None,
            "hardwareDeviceType": 5,
            "roleGroupId": 1,
            "bypassState": 0,
            "lockChangedByUser": None,
            "lockChangedByDeviceNumber": None,
            "lockChangedByDeviceType": None,
            "associatedOutputType": 0,
            "associatedOutputId": None,
            "owner": None,
            "panelUpdateTime": "2021-01-04T13:23:16Z",
            "updateTime": "2021-01-04T12:23:17Z",
            "chime": False,
            "securityMode": 16,
            "isOutdoorMode": None,
            "isBeepEnable": None,
            "fullExitBeepsEnabled": None,
            "doorBellEnabled": None,
            "subDeviceType": None,
            "panelDeviceId": None,
            "isNormallyOpen": None,
            "isPulseDevice": None,
            "utDeviceType": None,
            "additionalData": None,
            "addedOrResetTime": "2020-12-01T15:49:52Z",
            "PkId": 955560,
            "Id": 9,
            "Type": 38,
            "Name": "Video stue",
            "ParentDeviceId": None,
            "PanelId": 10039947,
        },
        {
            "key": 659939,
            "isTampered": False,
            "hasLowBattery": False,
            "hasSupervisionFault": False,
            "isOpen": None,
            "isLocked": False,
            "isLockout": None,
            "isTriggeredAlarm": False,
            "alarmType": 0,
            "userName": None,
            "serialNumber": "4XP1>Am@LIn?EoGPID:cNA",
            "dayPartition": False,
            "nightPartition": False,
            "rfLevel": None,
            "batteryLevel": None,
            "temperatureLevel": None,
            "subType": 2,
            "attributes": [
                {"name": "HOME_ID", "value": "01822E7D"},
                {"name": "RESET_FACTORY_SETTINGS_STATUS", "value": "Ok"},
                {"name": "NETWORK_UPDATE_STATUS", "value": "Done"},
                {"name": "NETWORK_UPDATE_STATUS_FAILED_DEVICES", "value": ""},
                {"name": "NETWORK_JOIN_STATUS", "value": ""},
                {"name": "REMOVED_NON_EXISTING_DEVICE", "value": ""},
                {"name": "ERROR_OCCURRED", "value": ""},
                {"name": "SERIES", "value": "500"},
                {"name": "VERSION", "value": "0"},
                {"name": "CONTROLLER_IS_SECONDARY", "value": "False"},
                {"name": "CONTROLLER_ON_OTHER_NETWORK", "value": "False"},
                {"name": "CONTROLLER_NODE_ID_SERVER_PRESENT", "value": "True"},
                {"name": "CONTROLLER_IS_REAL_PRIMARY", "value": "True"},
                {"name": "CONTROLLER_IS_SUC", "value": "True"},
                {"name": "NO_NODES_INCLUDED", "value": "True"},
            ],
            "hardwareDeviceType": None,
            "roleGroupId": 1,
            "bypassState": 0,
            "lockChangedByUser": None,
            "lockChangedByDeviceNumber": None,
            "lockChangedByDeviceType": None,
            "associatedOutputType": None,
            "associatedOutputId": None,
            "owner": None,
            "panelUpdateTime": "2020-12-01T15:40:38Z",
            "updateTime": "2021-01-03T06:57:25Z",
            "chime": False,
            "securityMode": None,
            "isOutdoorMode": None,
            "isBeepEnable": None,
            "fullExitBeepsEnabled": None,
            "doorBellEnabled": None,
            "subDeviceType": None,
            "panelDeviceId": None,
            "isNormallyOpen": None,
            "isPulseDevice": None,
            "utDeviceType": None,
            "additionalData": None,
            "addedOrResetTime": "2020-12-01T15:40:38Z",
            "PkId": 955540,
            "Id": 0,
            "Type": 116,
            "Name": "Z-WAVE® CONTROLLER-0",
            "ParentDeviceId": None,
            "PanelId": 10039947,
        },
        {
            "accessCode": "",
            "key": None,
            "isTampered": None,
            "hasLowBattery": None,
            "hasSupervisionFault": None,
            "isOpen": None,
            "isLocked": False,
            "isLockout": None,
            "isTriggeredAlarm": False,
            "alarmType": 0,
            "userName": "Patrick Toft Steffensen",
            "serialNumber": "04C9CB8EC2606780",
            "dayPartition": False,
            "nightPartition": False,
            "rfLevel": None,
            "batteryLevel": None,
            "temperatureLevel": None,
            "subType": None,
            "attributes": None,
            "hardwareDeviceType": None,
            "roleGroupId": 5,
            "bypassState": 0,
            "lockChangedByUser": None,
            "lockChangedByDeviceNumber": None,
            "lockChangedByDeviceType": None,
            "associatedOutputType": None,
            "associatedOutputId": None,
            "owner": 1,
            "panelUpdateTime": "2020-12-01T15:58:24Z",
            "updateTime": "2021-01-03T06:57:25Z",
            "chime": False,
            "securityMode": None,
            "isOutdoorMode": None,
            "isBeepEnable": None,
            "fullExitBeepsEnabled": None,
            "doorBellEnabled": None,
            "subDeviceType": None,
            "panelDeviceId": None,
            "isNormallyOpen": None,
            "isPulseDevice": None,
            "utDeviceType": None,
            "additionalData": None,
            "addedOrResetTime": "2020-12-01T15:58:24Z",
            "PkId": 955570,
            "Id": 1,
            "Type": 201,
            "Name": "Patrick",
            "ParentDeviceId": None,
            "PanelId": 10039947,
        },
        {
            "accessCode": "",
            "key": None,
            "isTampered": None,
            "hasLowBattery": None,
            "hasSupervisionFault": None,
            "isOpen": None,
            "isLocked": False,
            "isLockout": None,
            "isTriggeredAlarm": False,
            "alarmType": 0,
            "userName": "Patrick Toft Steffensen",
            "serialNumber": "04A1CBE6C2606780",
            "dayPartition": False,
            "nightPartition": False,
            "rfLevel": None,
            "batteryLevel": None,
            "temperatureLevel": None,
            "subType": None,
            "attributes": None,
            "hardwareDeviceType": None,
            "roleGroupId": 5,
            "bypassState": 0,
            "lockChangedByUser": None,
            "lockChangedByDeviceNumber": None,
            "lockChangedByDeviceType": None,
            "associatedOutputType": None,
            "associatedOutputId": None,
            "owner": 1,
            "panelUpdateTime": "2020-12-01T15:58:45Z",
            "updateTime": "2021-01-03T06:57:25Z",
            "chime": False,
            "securityMode": None,
            "isOutdoorMode": None,
            "isBeepEnable": None,
            "fullExitBeepsEnabled": None,
            "doorBellEnabled": None,
            "subDeviceType": None,
            "panelDeviceId": None,
            "isNormallyOpen": None,
            "isPulseDevice": None,
            "utDeviceType": None,
            "additionalData": None,
            "addedOrResetTime": "2020-12-01T15:58:45Z",
            "PkId": 955571,
            "Id": 2,
            "Type": 201,
            "Name": "Anna",
            "ParentDeviceId": None,
            "PanelId": 10039947,
        },
        {
            "accessCode": "",
            "key": None,
            "isTampered": None,
            "hasLowBattery": None,
            "hasSupervisionFault": None,
            "isOpen": None,
            "isLocked": False,
            "isLockout": None,
            "isTriggeredAlarm": False,
            "alarmType": 0,
            "userName": "Patrick Toft Steffensen",
            "serialNumber": "041DCC5DC2606781",
            "dayPartition": False,
            "nightPartition": False,
            "rfLevel": None,
            "batteryLevel": None,
            "temperatureLevel": None,
            "subType": None,
            "attributes": None,
            "hardwareDeviceType": None,
            "roleGroupId": 5,
            "bypassState": 0,
            "lockChangedByUser": None,
            "lockChangedByDeviceNumber": None,
            "lockChangedByDeviceType": None,
            "associatedOutputType": None,
            "associatedOutputId": None,
            "owner": 1,
            "panelUpdateTime": "2020-12-01T15:59:27Z",
            "updateTime": "2021-01-03T06:57:25Z",
            "chime": False,
            "securityMode": None,
            "isOutdoorMode": None,
            "isBeepEnable": None,
            "fullExitBeepsEnabled": None,
            "doorBellEnabled": None,
            "subDeviceType": None,
            "panelDeviceId": None,
            "isNormallyOpen": None,
            "isPulseDevice": None,
            "utDeviceType": None,
            "additionalData": None,
            "addedOrResetTime": "2020-12-01T15:59:27Z",
            "PkId": 955573,
            "Id": 3,
            "Type": 201,
            "Name": "Helle",
            "ParentDeviceId": None,
            "PanelId": 10039947,
        },
        {
            "accessCode": "3397",
            "key": None,
            "isTampered": None,
            "hasLowBattery": None,
            "hasSupervisionFault": None,
            "isOpen": None,
            "isLocked": False,
            "isLockout": None,
            "isTriggeredAlarm": False,
            "alarmType": 0,
            "userName": "guard_10039947",
            "serialNumber": "0475CB32C2606780",
            "dayPartition": False,
            "nightPartition": False,
            "rfLevel": None,
            "batteryLevel": None,
            "temperatureLevel": None,
            "subType": None,
            "attributes": None,
            "hardwareDeviceType": None,
            "roleGroupId": 1,
            "bypassState": 0,
            "lockChangedByUser": None,
            "lockChangedByDeviceNumber": None,
            "lockChangedByDeviceType": None,
            "associatedOutputType": None,
            "associatedOutputId": None,
            "owner": 3,
            "panelUpdateTime": "2020-12-01T17:07:45Z",
            "updateTime": "2021-01-03T06:57:25Z",
            "chime": False,
            "securityMode": None,
            "isOutdoorMode": None,
            "isBeepEnable": None,
            "fullExitBeepsEnabled": None,
            "doorBellEnabled": None,
            "subDeviceType": None,
            "panelDeviceId": None,
            "isNormallyOpen": None,
            "isPulseDevice": None,
            "utDeviceType": None,
            "additionalData": None,
            "addedOrResetTime": "2020-12-01T15:59:45Z",
            "PkId": 955574,
            "Id": 4,
            "Type": 201,
            "Name": "Vagt",
            "ParentDeviceId": None,
            "PanelId": 10039947,
        },
    ]

    print([StateDevice(x) for x in vals])
